@@ -5,10 +5,16 @@ A command-line tool that automatically generates conventional commit messages us
 Supports multiple AI providers including OpenRouter, Ollama, and custom providers.
 """
 
-__version__ = "0.1.0"
+__version__ = "1.0.9"
 __author__ = "Mobio Team"
 __email__ = "dev@mobio.vn"
 
+try:
+    from pkg_resources import declare_namespace
+    declare_namespace(__name__)
+except ImportError:
+    pass
+
 from .core import generate_commit_message, generate_changelog
 from .cli import main
 
